@@ -31,7 +31,7 @@ from bandit.core import node_visitor as b_node_visitor
 from bandit.core import test_set as b_test_set
 
 
-logger = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class BanditManager():
@@ -39,7 +39,7 @@ class BanditManager():
     scope = []
 
     def __init__(self, config, agg_type, debug=False, verbose=False,
-                 profile={}, ignore_nosec=False):
+                 profile=None, ignore_nosec=False):
         '''Get logger, config, AST handler, and result store ready
 
         :param config: config options object
@@ -53,6 +53,8 @@ class BanditManager():
         '''
         self.debug = debug
         self.verbose = verbose
+        if not profile:
+            profile = {}
         self.ignore_nosec = ignore_nosec
         self.b_conf = config
         self.files_list = []
@@ -86,7 +88,7 @@ class BanditManager():
             jdata = json.loads(data)
             items = [issue.issue_from_dict(j) for j in jdata["results"]]
         except Exception as e:
-            logger.warning("Failed to load baseline data: %s", e)
+            LOG.warning("Failed to load baseline data: %s", e)
         self.baseline = items
 
     def filter_results(self, sev_filter, conf_filter):
@@ -181,8 +183,8 @@ class BanditManager():
                     files_list.update(new_files)
                     excluded_files.update(newly_excluded)
                 else:
-                    logger.warning("Skipping directory (%s), use -r flag to "
-                                   "scan contents", fname)
+                    LOG.warning("Skipping directory (%s), use -r flag to "
+                                "scan contents", fname)
 
             else:
                 # if the user explicitly mentions a file on command line,
@@ -212,7 +214,7 @@ class BanditManager():
         new_files_list = list(self.files_list)
 
         for count, fname in enumerate(self.files_list):
-            logger.debug("working on file : %s", fname)
+            LOG.debug("working on file : %s", fname)
 
             if len(self.files_list) > self.progress:
                 # is it time to update the progress indicator?
@@ -220,48 +222,12 @@ class BanditManager():
                     sys.stderr.write("%s.. " % count)
                     sys.stderr.flush()
             try:
-                with open(fname, 'rb') as fdata:
-                    try:
-                        # parse the current file
-                        data = fdata.read()
-                        lines = data.splitlines()
-                        self.metrics.begin(fname)
-                        self.metrics.count_locs(lines)
-                        if self.ignore_nosec:
-                            nosec_lines = set()
-                        else:
-                            nosec_lines = set(
-                                lineno + 1 for
-                                (lineno, line) in enumerate(lines)
-                                if b'#nosec' in line or b'# nosec' in line)
-                        score = self._execute_ast_visitor(fname, data,
-                                                          nosec_lines)
-                        self.scores.append(score)
-                        self.metrics.count_issues([score, ])
-                    except KeyboardInterrupt as e:
-                        sys.exit(2)
-                    except SyntaxError as e:
-                        self.skipped.append((
-                            fname,
-                            "syntax error while parsing AST from file"
-                        ))
-                        new_files_list.remove(fname)
-                    except Exception as e:
-                        logger.error(
-                            "Exception occurred when executing tests against "
-                            "{0}. Run \"bandit --debug {0}\" to see the full "
-                            "traceback.".format(fname)
-                        )
-                        self.skipped.append(
-                            (fname, 'exception while scanning file')
-                        )
-                        new_files_list.remove(fname)
-                        logger.debug("  Exception string: %s", e)
-                        logger.debug(
-                            "  Exception traceback: %s",
-                            traceback.format_exc()
-                        )
-                        continue
+                if fname == '-':
+                    sys.stdin = os.fdopen(sys.stdin.fileno(), 'rb', 0)
+                    self._parse_file('<stdin>', sys.stdin, new_files_list)
+                else:
+                    with open(fname, 'rb') as fdata:
+                        self._parse_file(fname, fdata, new_files_list)
             except IOError as e:
                 self.skipped.append((fname, e.strerror))
                 new_files_list.remove(fname)
@@ -276,6 +242,38 @@ class BanditManager():
         # do final aggregation of metrics
         self.metrics.aggregate()
 
+    def _parse_file(self, fname, fdata, new_files_list):
+        try:
+            # parse the current file
+            data = fdata.read()
+            lines = data.splitlines()
+            self.metrics.begin(fname)
+            self.metrics.count_locs(lines)
+            if self.ignore_nosec:
+                nosec_lines = set()
+            else:
+                nosec_lines = set(
+                    lineno + 1 for
+                    (lineno, line) in enumerate(lines)
+                    if b'#nosec' in line or b'# nosec' in line)
+            score = self._execute_ast_visitor(fname, data, nosec_lines)
+            self.scores.append(score)
+            self.metrics.count_issues([score, ])
+        except KeyboardInterrupt as e:
+            sys.exit(2)
+        except SyntaxError as e:
+            self.skipped.append((fname,
+                                 "syntax error while parsing AST from file"))
+            new_files_list.remove(fname)
+        except Exception as e:
+            LOG.error("Exception occurred when executing tests against "
+                      "%s. Run \"bandit --debug %s\" to see the full "
+                      "traceback.", fname, fname)
+            self.skipped.append((fname, 'exception while scanning file'))
+            new_files_list.remove(fname)
+            LOG.debug("  Exception string: %s", e)
+            LOG.debug("  Exception traceback: %s", traceback.format_exc())
+
     def _execute_ast_visitor(self, fname, data, nosec_lines):
         '''Execute AST parse on each file
 
@@ -294,8 +292,10 @@ class BanditManager():
         return score
 
 
-def _get_files_from_dir(files_dir, included_globs=['*.py'],
+def _get_files_from_dir(files_dir, included_globs=None,
                         excluded_path_strings=None):
+    if not included_globs:
+        included_globs = ['*.py']
     if not excluded_path_strings:
         excluded_path_strings = []
 
