@@ -19,13 +19,16 @@ import collections
 import logging
 
 
-logger = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class BanditMetaAst():
 
     nodes = collections.OrderedDict()
 
+    def __init__(self):
+        pass
+
     def add_node(self, node, parent_id, depth):
         '''Add a node to the AST node collection
 
@@ -35,7 +38,7 @@ class BanditMetaAst():
         :return: -
         '''
         node_id = hex(id(node))
-        logger.debug('adding node : %s [%s]', node_id, depth)
+        LOG.debug('adding node : %s [%s]', node_id, depth)
         self.nodes[node_id] = {
             'raw': node, 'parent_id': parent_id, 'depth': depth
         }
