@@ -18,8 +18,7 @@ import ast
 import re
 
 import bandit
-from bandit.core.test_properties import checks
-from bandit.core.test_properties import takes_config
+from bandit.core import test_properties as test
 
 
 def _has_special_characters(command):
@@ -47,10 +46,62 @@ def _evaluate_shell_call(context):
         return bandit.HIGH
 
 
-@takes_config('shell_injection')
-@checks('Call')
+def gen_config(name):
+    if name == 'shell_injection':
+        return {
+            # Start a process using the subprocess module, or one of its
+            # wrappers.
+            'subprocess':
+            ['subprocess.Popen',
+             'subprocess.call',
+             'subprocess.check_call',
+             'subprocess.check_output',
+             'utils.execute',
+             'utils.execute_with_timeout'],
+
+            # Start a process with a function vulnerable to shell injection.
+            'shell':
+            ['os.system',
+             'os.popen',
+             'os.popen2',
+             'os.popen3',
+             'os.popen4',
+             'popen2.popen2',
+             'popen2.popen3',
+             'popen2.popen4',
+             'popen2.Popen3',
+             'popen2.Popen4',
+             'commands.getoutput',
+             'commands.getstatusoutput'],
+
+            # Start a process with a function that is not vulnerable to shell
+            # injection.
+            'no_shell':
+            ['os.execl',
+             'os.execle',
+             'os.execlp',
+             'os.execlpe',
+             'os.execv',
+             'os.execve',
+             'os.execvp',
+             'os.execvpe',
+             'os.spawnl',
+             'os.spawnle',
+             'os.spawnlp',
+             'os.spawnlpe',
+             'os.spawnv',
+             'os.spawnve',
+             'os.spawnvp',
+             'os.spawnvpe',
+             'os.startfile']
+            }
+
+
+@test.takes_config('shell_injection')
+@test.checks('Call')
+@test.test_id('B602')
 def subprocess_popen_with_shell_equals_true(context, config):
-    """subprocess_popen_with_shell_equals_true
+    """**B602: Test for use of popen with shell equals true**
 
     Python possesses many mechanisms to invoke an external executable. However,
     doing so may present a security issue if appropriate care is not taken to
@@ -62,7 +113,7 @@ def subprocess_popen_with_shell_equals_true(context, config):
     invocation is dangerous as it is vulnerable to various shell injection
     attacks. Great care should be taken to sanitize all input in order to
     mitigate this risk. Calls of this type are identified by a parameter of
-    "shell=True" being given.
+    'shell=True' being given.
 
     Additionally, this plugin scans the command string given and adjusts its
     reported severity based on how it is presented. If the command string is a
@@ -82,7 +133,7 @@ def subprocess_popen_with_shell_equals_true(context, config):
     - :doc:`../plugins/start_process_with_a_shell`
     - :doc:`../plugins/start_process_with_partial_path`
 
-    Config Options:
+    **Config Options:**
 
     This plugin test shares a configuration with others in the same family,
     namely `shell_injection`. This configuration is divided up into three
@@ -104,7 +155,7 @@ def subprocess_popen_with_shell_equals_true(context, config):
                 - subprocess.call
 
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -131,12 +182,12 @@ def subprocess_popen_with_shell_equals_true(context, config):
         27  subprocess.Popen('/bin/ls %s' % ('something',), shell=True)
         28  subprocess.Popen('/bin/ls {}'.format('something'), shell=True)
 
-    References:
+    .. seealso::
 
-    - https://security.openstack.org
-    - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
-    - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
-    - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
+     - https://security.openstack.org
+     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
+     - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
 
     .. versionadded:: 0.9.0
     """
@@ -148,31 +199,35 @@ def subprocess_popen_with_shell_equals_true(context, config):
                     return bandit.Issue(
                         severity=bandit.LOW,
                         confidence=bandit.HIGH,
-                        text="subprocess call with shell=True seems safe, but "
-                             "may be changed in the future, consider "
-                             "rewriting without shell"
+                        text='subprocess call with shell=True seems safe, but '
+                             'may be changed in the future, consider '
+                             'rewriting without shell',
+                        lineno=context.get_lineno_for_call_arg('shell'),
                     )
                 elif sev == bandit.MEDIUM:
                     return bandit.Issue(
                         severity=bandit.MEDIUM,
                         confidence=bandit.HIGH,
-                        text="call with shell=True contains special shell "
-                             "characters, consider moving extra logic into "
-                             "Python code"
+                        text='call with shell=True contains special shell '
+                             'characters, consider moving extra logic into '
+                             'Python code',
+                        lineno=context.get_lineno_for_call_arg('shell'),
                     )
                 else:
                     return bandit.Issue(
                         severity=bandit.HIGH,
                         confidence=bandit.HIGH,
-                        text="subprocess call with shell=True identified, "
-                             "security issue."
+                        text='subprocess call with shell=True identified, '
+                             'security issue.',
+                        lineno=context.get_lineno_for_call_arg('shell'),
                     )
 
 
-@takes_config('shell_injection')
-@checks('Call')
+@test.takes_config('shell_injection')
+@test.checks('Call')
+@test.test_id('B603')
 def subprocess_without_shell_equals_true(context, config):
-    """subprocess_without_shell_equals_true
+    """**B603: Test for use of subprocess with shell equals true**
 
     Python possesses many mechanisms to invoke an external executable. However,
     doing so may present a security issue if appropriate care is not taken to
@@ -196,7 +251,7 @@ def subprocess_without_shell_equals_true(context, config):
     - :doc:`../plugins/start_process_with_a_shell`
     - :doc:`../plugins/start_process_with_partial_path`
 
-    Config Options:
+    **Config Options:**
 
     This plugin test shares a configuration with others in the same family,
     namely `shell_injection`. This configuration is divided up into three
@@ -216,8 +271,7 @@ def subprocess_without_shell_equals_true(context, config):
                 - subprocess.Popen
                 - subprocess.call
 
-
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -228,12 +282,12 @@ def subprocess_without_shell_equals_true(context, config):
         23    subprocess.check_output(['/bin/ls', '-l'])
         24
 
-    References:
+    .. seealso::
 
-    - https://security.openstack.org
-    - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
-    - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
-    - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
+     - https://security.openstack.org
+     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
+     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.9.0
     """
@@ -242,15 +296,17 @@ def subprocess_without_shell_equals_true(context, config):
             return bandit.Issue(
                 severity=bandit.LOW,
                 confidence=bandit.HIGH,
-                text="subprocess call - check for execution of untrusted "
-                     "input."
+                text='subprocess call - check for execution of untrusted '
+                     'input.',
+                lineno=context.get_lineno_for_call_arg('shell'),
             )
 
 
-@takes_config('shell_injection')
-@checks('Call')
+@test.takes_config('shell_injection')
+@test.checks('Call')
+@test.test_id('B604')
 def any_other_function_with_shell_equals_true(context, config):
-    """any_other_function_with_shell_equals_true
+    """**B604: Test for any function with shell equals true**
 
     Python possesses many mechanisms to invoke an external executable. However,
     doing so may present a security issue if appropriate care is not taken to
@@ -272,7 +328,7 @@ def any_other_function_with_shell_equals_true(context, config):
     - :doc:`../plugins/start_process_with_a_shell`
     - :doc:`../plugins/start_process_with_partial_path`
 
-    Config Options:
+    **Config Options:**
 
     This plugin test shares a configuration with others in the same family,
     namely `shell_injection`. This configuration is divided up into three
@@ -294,7 +350,7 @@ def any_other_function_with_shell_equals_true(context, config):
                          utils.execute, utils.execute_with_timeout]
 
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -306,32 +362,29 @@ def any_other_function_with_shell_equals_true(context, config):
         9 Popen('/bin/gcc --version', shell=True)
         10
 
-    References:
+    .. seealso::
 
      - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html  # noqa
-    """
-    '''Alerts on any function call that includes a shell=True parameter.
-
-    Multiple "helpers" with varying names have been identified across
-    various OpenStack projects.
 
     .. versionadded:: 0.9.0
-    '''
+    """
     if config and context.call_function_name_qual not in config['subprocess']:
         if context.check_call_arg_value('shell', 'True'):
             return bandit.Issue(
                 severity=bandit.MEDIUM,
                 confidence=bandit.LOW,
-                text="Function call with shell=True parameter identifed, "
-                     "possible security issue."
+                text='Function call with shell=True parameter identified, '
+                     'possible security issue.',
+                lineno=context.get_lineno_for_call_arg('shell'),
                 )
 
 
-@takes_config('shell_injection')
-@checks('Call')
+@test.takes_config('shell_injection')
+@test.checks('Call')
+@test.test_id('B605')
 def start_process_with_a_shell(context, config):
-    """start_process_with_a_shell
+    """**B605: Test for starting a process with a shell**
 
     Python possesses many mechanisms to invoke an external executable. However,
     doing so may present a security issue if appropriate care is not taken to
@@ -354,7 +407,7 @@ def start_process_with_a_shell(context, config):
     - :doc:`../plugins/start_process_with_partial_path`
     - :doc:`../plugins/subprocess_popen_with_shell_equals_true`
 
-    Config Options:
+    **Config Options:**
 
     This plugin test shares a configuration with others in the same family,
     namely `shell_injection`. This configuration is divided up into three
@@ -381,7 +434,7 @@ def start_process_with_a_shell(context, config):
                 - commands.getoutput
                 - commands.getstatusoutput
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -391,12 +444,12 @@ def start_process_with_a_shell(context, config):
         2
         3   os.system('/bin/echo hi')
 
-    References:
+    .. seealso::
 
-    - https://security.openstack.org
-    - https://docs.python.org/2/library/os.html#os.system
-    - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
-    - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
+     - https://security.openstack.org
+     - https://docs.python.org/2/library/os.html#os.system
+     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.10.0
     """
@@ -407,31 +460,32 @@ def start_process_with_a_shell(context, config):
                 return bandit.Issue(
                     severity=bandit.LOW,
                     confidence=bandit.HIGH,
-                    text="Starting a process with a shell: "
-                         "Seems safe, but may be changed in the future, "
-                         "consider rewriting without shell"
+                    text='Starting a process with a shell: '
+                         'Seems safe, but may be changed in the future, '
+                         'consider rewriting without shell'
                 )
             elif sev == bandit.MEDIUM:
                 return bandit.Issue(
                     severity=bandit.MEDIUM,
                     confidence=bandit.HIGH,
-                    text="Starting a process with a shell and special shell "
-                         "characters, consider moving extra logic into "
-                         "Python code"
+                    text='Starting a process with a shell and special shell '
+                         'characters, consider moving extra logic into '
+                         'Python code'
                 )
             else:
                 return bandit.Issue(
                     severity=bandit.HIGH,
                     confidence=bandit.HIGH,
-                    text="Starting a process with a shell, possible injection"
-                         " detected, security issue."
+                    text='Starting a process with a shell, possible injection'
+                         ' detected, security issue.'
                 )
 
 
-@takes_config('shell_injection')
-@checks('Call')
+@test.takes_config('shell_injection')
+@test.checks('Call')
+@test.test_id('B606')
 def start_process_with_no_shell(context, config):
-    """start_process_with_no_shell
+    """**B606: Test for starting a process with no shell**
 
     Python possesses many mechanisms to invoke an external executable. However,
     doing so may present a security issue if appropriate care is not taken to
@@ -452,7 +506,7 @@ def start_process_with_no_shell(context, config):
     - :doc:`../plugins/start_process_with_partial_path`
     - :doc:`../plugins/subprocess_popen_with_shell_equals_true`
 
-    Config Options:
+    **Config Options:**
 
     This plugin test shares a configuration with others in the same family,
     namely `shell_injection`. This configuration is divided up into three
@@ -484,7 +538,7 @@ def start_process_with_no_shell(context, config):
                 - os.spawnvpe
                 - os.startfile
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -496,12 +550,12 @@ def start_process_with_no_shell(context, config):
         8   os.spawnve(mode, path, args, env)
         9   os.spawnvp(mode, file, args)
 
-    References:
+    .. seealso::
 
-    - https://security.openstack.org
-    - https://docs.python.org/2/library/os.html#os.system
-    - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
-    - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
+     - https://security.openstack.org
+     - https://docs.python.org/2/library/os.html#os.system
+     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.10.0
     """
@@ -510,14 +564,15 @@ def start_process_with_no_shell(context, config):
         return bandit.Issue(
             severity=bandit.LOW,
             confidence=bandit.MEDIUM,
-            text="Starting a process without a shell."
+            text='Starting a process without a shell.'
         )
 
 
-@takes_config('shell_injection')
-@checks('Call')
+@test.takes_config('shell_injection')
+@test.checks('Call')
+@test.test_id('B607')
 def start_process_with_partial_path(context, config):
-    """start_process_with_partial_path
+    """**B607: Test for starting a process with a partial path**
 
     Python possesses many mechanisms to invoke an external executable. If the
     desired executable path is not fully qualified relative to the filesystem
@@ -536,7 +591,7 @@ def start_process_with_partial_path(context, config):
     looking for paths that do not start at the filesystem root, that is, do not
     have a leading '/' character.
 
-    Config Options:
+    **Config Options:**
 
     This plugin test shares a configuration with others in the same family,
     namely `shell_injection`. This configuration is divided up into three
@@ -571,7 +626,7 @@ def start_process_with_partial_path(context, config):
                 - os.execle
 
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -581,10 +636,10 @@ def start_process_with_partial_path(context, config):
         2    from subprocess import Popen as pop
         3    pop('gcc --version', shell=False)
 
-    References:
+    .. seealso::
 
-    - https://security.openstack.org
-    - https://docs.python.org/2/library/os.html#process-management
+     - https://security.openstack.org
+     - https://docs.python.org/2/library/os.html#process-management
 
     .. versionadded:: 0.13.0
     """
@@ -601,9 +656,9 @@ def start_process_with_partial_path(context, config):
                 node = node.elts[0]
 
             # make sure the param is a string literal and not a var name
-            if(isinstance(node, ast.Str) and node.s[0] not in delims):
+            if isinstance(node, ast.Str) and node.s[0] not in delims:
                 return bandit.Issue(
                     severity=bandit.LOW,
                     confidence=bandit.HIGH,
-                    text="Starting a process with a partial executable path"
+                    text='Starting a process with a partial executable path'
                 )
